@@ -1,12 +1,16 @@
 from pyais.messages import NMEAMessage, AISMessage
-from pyais.stream import TCPStream, FileReaderStream
+from pyais.stream import TCPStream, FileReaderStream, IterMessages
+from pyais.decode import decode_msg
+
 
 __license__ = 'MIT'
-__version__ = '1.3.1'
+__version__ = '1.6.0'
 
 __all__ = (
+    'decode_msg',
     'NMEAMessage',
     'AISMessage',
     'TCPStream',
+    'IterMessages',
     'FileReaderStream'
 )
