@@ -1,8 +1,9 @@
 from functools import partial
-from typing import Any, Dict
+from typing import Any, Dict, Union
 
 import bitarray  # type: ignore
 
+from pyais import messages
 from pyais.constants import (
     NavigationStatus,
     ManeuverIndicator,
@@ -14,7 +15,6 @@ from pyais.constants import (
     NavAid
 )
 from pyais.exceptions import UnknownMessageException
-from pyais import messages
 from pyais.util import get_int, encode_bin_as_ascii6, get_mmsi
 
 
@@ -698,3 +698,28 @@ def decode(msg: "messages.NMEAMessage") -> Dict[str, Any]:
     @param msg: A object of type NMEAMessage to decode
     """
     return _decode(msg)
+
+
+def decode_msg(*args: Union[str, bytes]) -> Dict[str, Any]:
+    """
+    Decode single message.
+
+    This method is ONLY meant to decode a SINGLE (multiline) message.
+    Pass every part of a single as an argument.
+
+    @param args: A AIS message, that can be either bytes or str (UTF-8) encoded.
+                For multiline messages, pass all parts.
+    @return: A dictionary of the decoded key-value pairs.
+
+    """
+    # Make everything bytes
+    message_as_bytes = tuple(msg.encode('utf-8') if isinstance(msg, str) else msg for msg in args)
+
+    # Create temporary messages
+    temp = [messages.NMEAMessage(m) for m in message_as_bytes]
+
+    # Assemble temporary messages
+    final = messages.NMEAMessage.assemble_from_iterable(temp)
+
+    # Decode
+    return final.decode(silent=False).content  # type: ignore
