@@ -1,10 +1,10 @@
-from pyais.stream import ByteStream
-
-from pyais.exceptions import UnknownMessageException
 import unittest
-from pyais.messages import AISMessage, NMEAMessage
+
 from pyais.ais_types import AISType
 from pyais.constants import ManeuverIndicator, NavigationStatus, ShipType, NavAid, EpfdType
+from pyais.exceptions import UnknownMessageException
+from pyais.messages import AISMessage, NMEAMessage
+from pyais.stream import ByteStream
 
 
 class TestAIS(unittest.TestCase):
@@ -36,12 +36,13 @@ class TestAIS(unittest.TestCase):
         "ais_id": 1,
         "raw": "!AIVDM,1,1,,A,15NPOOPP00o?b=bE`UNv4?w428D;,0*24",
         "talker": "AI",
-        "msg_type": "VDM",
-        "count": 1,
-        "index": 1,
-        "seq_id": "",
+        "type": "VDM",
+        "message_fragments": 1,
+        "fragment_number": 1,
+        "message_id": null,
         "channel": "A",
-        "data": "15NPOOPP00o?b=bE`UNv4?w428D;",
+        "payload": "15NPOOPP00o?b=bE`UNv4?w428D;",
+        "fill_bits": 0,
         "checksum": 36,
         "bit_array": "000001000101011110100000011111011111100000100000000000000000110111001111101010001101101010010101101000100101011110111110000100001111111111000100000010001000010100001011"
     },
@@ -52,18 +53,18 @@ class TestAIS(unittest.TestCase):
         "status": 0,
         "turn": -128,
         "speed": 0.0,
-        "accuracy": true,
+        "accuracy": 1,
         "lon": -122.40823166666667,
         "lat": 37.808418333333336,
         "course": 360.0,
         "heading": 511,
         "second": 34,
         "maneuver": 0,
-        "raim": true,
+        "raim": 1,
         "radio": 34059
     }
 }"""
-        assert json_dump == text
+        self.assertEqual(json_dump, text)
 
     def test_msg_type(self):
         """
@@ -115,6 +116,11 @@ class TestAIS(unittest.TestCase):
         assert msg['maneuver'] == ManeuverIndicator.NotAvailable
         assert msg['raim']
 
+        msg = NMEAMessage(b"!AIVDM,1,1,,B,181:Kjh01ewHFRPDK1s3IRcn06sd,0*08").decode()
+        assert msg['course'] == 87.0
+        assert msg['mmsi'] == "538090443"
+        assert msg['speed'] == 10.9
+
     def test_decode_pos_1_2_3(self):
         # weired message of type 0 as part of issue #4
         msg: NMEAMessage = NMEAMessage(b"!AIVDM,1,1,,B,0S9edj0P03PecbBN`ja@0?w42cFC,0*7C")
@@ -188,6 +194,7 @@ class TestAIS(unittest.TestCase):
         assert msg['to_starboard'] == 31
         assert msg['draught'] == 12.2
         assert msg['destination'] == "NEW YORK"
+        assert msg['dte'] == 0
 
     def test_msg_type_6(self):
         msg = NMEAMessage(b"!AIVDM,1,1,,B,6B?n;be:cbapalgc;i6?Ow4,2*4A").decode()
@@ -506,8 +513,6 @@ class TestAIS(unittest.TestCase):
         assert msg['gnss'] == 0
 
     def test_broken_messages(self):
-        # Not valid
-        assert not NMEAMessage(b"AIVDM,2,2,1,B,00000000000,2*26").is_valid
         # Undefined epfd
         assert NMEAMessage(b"!AIVDM,1,1,,B,4>O7m7Iu@<9qUfbtm`vSnwvH20S8,0*46").decode()['epfd'] == EpfdType.Undefined
 
@@ -565,15 +570,16 @@ class TestAIS(unittest.TestCase):
         "ais_id": 37,
         "raw": "!AIVDM,1,1,,A,U31<0OOP000CshrMdl600?wP00SL,0*43",
         "talker": "AI",
-        "msg_type": "VDM",
-        "count": 1,
-        "index": 1,
-        "seq_id": "",
+        "type": "VDM",
+        "message_fragments": 1,
+        "fragment_number": 1,
+        "message_id": null,
         "channel": "A",
-        "data": "U31<0OOP000CshrMdl600?wP00SL",
+        "payload": "U31<0OOP000CshrMdl600?wP00SL",
+        "fill_bits": 0,
         "checksum": 67,
         "bit_array": "100101000011000001001100000000011111011111100000000000000000000000010011111011110000111010011101101100110100000110000000000000001111111111100000000000000000100011011100"
     },
     "decoded": {}
 }"""
-        assert nmea.decode().to_json() == text
+        self.assertEqual(nmea.decode().to_json(), text)
